@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -73,7 +73,7 @@ public abstract class AbstractGroupAction implements AJAXActionService {
             }
             return perform(groupRequest);
         } catch (JSONException e) {
-            throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
+            throw AjaxExceptionCodes.ILLEGAL_REQUEST_BODY.create(e, e.getMessage());
         }
     }
 
